import { Body, ContentType, Controller, Post, Req, UseBefore } from 'routing-controllers';
import { OpenAPI } from 'routing-controllers-openapi';
import RawBodyMiddleware from '../middlewares/RawBody';
import { ImportRunner } from '../models/actions/ImportRunner';
import { ImportSchoolRunner } from '../models/actions/ImportSchoolRunner';
import { ResponseRunner } from '../models/responses/ResponseRunner';
import { RunnerController } from './RunnerController';

@Controller()
//@Authorized("IMPORT:read")
export class ImportController {
    private runnerController: RunnerController;

    /**
     * Gets the repository of this controller's model/entity.
     */
    constructor() {
        this.runnerController = new RunnerController();
    }

    @Post('/runners/import')
    @ContentType("application/json")
    @OpenAPI({ description: "Create new runners from json" })
    async postJSON(@Body({ validate: true, type: ImportSchoolRunner }) importRunners: ImportRunner[]) {
        let responseRunners: ResponseRunner[] = new Array<ResponseRunner>();
        for await (let runner of importRunners) {
            responseRunners.push(await this.runnerController.post(await runner.toCreateRunner(1)));
        }
        return responseRunners;
    }

    @Post('/runners/import/csv')
    @ContentType("text/csv")
    @UseBefore(RawBodyMiddleware)
    @OpenAPI({ description: "Create new runners from csv" })
    postCSV(@Req() request: any) {
        console.log(request.rawBody.toString())
        throw new Error("Not implemented yet.");
    }
}